Moirai is a font that experiments with stroke movement with visibility and legibility. It is designed to draw, arrange, and delete strokes of letters to have the minimum strokes and slopes necessary for that letter to be recognized. The shapes surrounding the thick space with thin, round lines give a lovely impression, while also creating a light and lyrical atmosphere.

To contribute, please visit github.com/JAMO-TYPEFACE/Moirai.